import { FormatId, IAudioMetadata, ICommonTagsResult, IFormat, INativeAudioMetadata, INativeTags, IOptions } from '../type';
import { IGenericTag, TagType } from "./GenericTagTypes";
/**
 * Combines all generic-tag-mappers for each tag type
 */
export interface INativeMetadataCollector {
    /**
     * Only use this for reading
     */
    readonly format: IFormat;
    readonly native: INativeTags;
    /**
     * @returns {boolean} true if one or more tags have been found
     */
    hasAny(): boolean;
    setFormat(key: FormatId, value: any): any;
    addTag(tagType: string, tagId: string, value: any): any;
}
/**
 * Provided to the parser to uodate the metadata result.
 * Responsible for triggering async updates
 */
export declare class MetadataCollector implements INativeMetadataCollector {
    private opts;
    readonly format: IFormat;
    readonly native: INativeTags;
    readonly common: ICommonTagsResult;
    /**
     * Keeps track of origin priority for each mapped id
     */
    private readonly commonOrigin;
    /**
     * Maps a tag type to a priority
     */
    private readonly originPriority;
    private tagMapper;
    constructor(opts: IOptions);
    /**
     * @returns {boolean} true if one or more tags have been found
     */
    hasAny(): boolean;
    setFormat(key: FormatId, value: any): void;
    addTag(tagType: TagType, tagId: string, value: any): void;
    getNativeMetadata(): INativeAudioMetadata;
    postMap(tagType: TagType | 'artificial', tag: IGenericTag): any;
    /**
     * Convert native tags to common tags
     * @returns {IAudioMetadata} Native + common tags
     */
    toCommonMetadata(): IAudioMetadata;
    /**
     * Convert native tag to common tags
     */
    private toCommon;
    /**
     * Set generic tag
     * @param {GenericTagId} tagId
     * @param {TagType} tagType originating header type, used to prioritize concurrent mappings
     * @param value
     */
    private setGenericTag;
}
export declare function joinArtists(artists: string[]): string;
